==> request-tracker4_4.4.4+dfsg.orig-third-party-source.tar.gz: rt-4.4.4/devel/third-party/ckeditor-src/plugins/link/lang/cy.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'cy', {
	acccessKey: 'Allwedd Mynediad',
	advanced: 'Uwch',
	advisoryContentType: 'Math y Cynnwys Cynghorol',
	advisoryTitle: 'Teitl Cynghorol',
	anchor: {
		toolbar: 'Angor',
		menu: 'Golygu\'r Angor',
		title: 'Priodweddau\'r Angor',
		name: 'Enw\'r Angor',
		errorName: 'Teipiwch enw\'r angor',
		remove: 'Tynnwch yr Angor'
	},
	anchorId: 'Gan Id yr Elfen',
	anchorName: 'Gan Enw\'r Angor',
	charset: 'Set Nodau\'r Adnodd Cysylltiedig',
	cssClasses: 'Dosbarthiadau Dalen Arddull',
	emailAddress: 'Cyfeiriad E-Bost',
	emailBody: 'Corff y Neges',
	emailSubject: 'Testun y Neges',
	id: 'Id',
	info: 'Gwyb y Ddolen',
	langCode: 'Cod Iaith',
	langDir: 'Cyfeiriad Iaith',
	langDirLTR: 'Chwith i\'r Dde (LTR)',
	langDirRTL: 'Dde i\'r Chwith (RTL)',
	menu: 'Golygu Dolen',
	name: 'Enw',
	noAnchors: '(Dim angorau ar gael yn y ddogfen)',
	noEmail: 'Teipiwch gyfeiriad yr e-bost',
	noUrl: 'Teipiwch URL y ddolen',
	other: '<eraill>',
	popupDependent: 'Dibynnol (Netscape)',
	popupFeatures: 'Nodweddion Ffenestr Bop',
	popupFullScreen: 'Sgrin Llawn (IE)',
	popupLeft: 'Safle Chwith',
	popupLocationBar: 'Bar Safle',
	popupMenuBar: 'Dewislen',
	popupResizable: 'Ailfeintiol',
	popupScrollBars: 'Barrau Sgrolio',
	popupStatusBar: 'Bar Statws',
	popupToolbar: 'Bar Offer',
	popupTop: 'Safle Top',
	rel: 'Perthynas',
	selectAnchor: 'Dewiswch Angor',
	styles: 'Arddull',
	tabIndex: 'Indecs Tab',
	target: 'Targed',
	targetFrame: '<ffrâm>',
	targetFrameName: 'Enw Ffrâm y Targed',
	targetPopup: '<ffenestr bop>',
	targetPopupName: 'Enw Ffenestr Bop',
	title: 'Dolen',
	toAnchor: 'Dolen at angor yn y testun',
	toEmail: 'E-bost',
	toUrl: 'URL',
	toolbar: 'Dolen',
	type: 'Math y Ddolen',
	unlink: 'Datgysylltu',
	upload: 'Lanlwytho'
} );

==> request-tracker5_5.0.3+dfsg.orig-third-party-source.tar.gz: rt-5.0.3/devel/third-party/ckeditor-src/plugins/link/lang/cy.js <==
﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'cy', {
	acccessKey: 'Allwedd Mynediad',
	advanced: 'Uwch',
	advisoryContentType: 'Math y Cynnwys Cynghorol',
	advisoryTitle: 'Teitl Cynghorol',
	anchor: {
		toolbar: 'Angor',
		menu: 'Golygu\'r Angor',
		title: 'Priodweddau\'r Angor',
		name: 'Enw\'r Angor',
		errorName: 'Teipiwch enw\'r angor',
		remove: 'Tynnwch yr Angor'
	},
	anchorId: 'Gan Id yr Elfen',
	anchorName: 'Gan Enw\'r Angor',
	charset: 'Set Nodau\'r Adnodd Cysylltiedig',
	cssClasses: 'Dosbarthiadau Dalen Arddull',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'Cyfeiriad E-Bost',
	emailBody: 'Corff y Neges',
	emailSubject: 'Testun y Neges',
	id: 'Id',
	info: 'Gwyb y Ddolen',
	langCode: 'Cod Iaith',
	langDir: 'Cyfeiriad Iaith',
	langDirLTR: 'Chwith i\'r Dde (LTR)',
	langDirRTL: 'Dde i\'r Chwith (RTL)',
	menu: 'Golygu Dolen',
	name: 'Enw',
	noAnchors: '(Dim angorau ar gael yn y ddogfen)',
	noEmail: 'Teipiwch gyfeiriad yr e-bost',
	noUrl: 'Teipiwch URL y ddolen',
	noTel: 'Please type the phone number', // MISSING
	other: '<eraill>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Dibynnol (Netscape)',
	popupFeatures: 'Nodweddion Ffenestr Bop',
	popupFullScreen: 'Sgrin Llawn (IE)',
	popupLeft: 'Safle Chwith',
	popupLocationBar: 'Bar Safle',
	popupMenuBar: 'Dewislen',
	popupResizable: 'Ailfeintiol',
	popupScrollBars: 'Barrau Sgrolio',
	popupStatusBar: 'Bar Statws',
	popupToolbar: 'Bar Offer',
	popupTop: 'Safle Top',
	rel: 'Perthynas',
	selectAnchor: 'Dewiswch Angor',
	styles: 'Arddull',
	tabIndex: 'Indecs Tab',
	target: 'Targed',
	targetFrame: '<ffrâm>',
	targetFrameName: 'Enw Ffrâm y Targed',
	targetPopup: '<ffenestr bop>',
	targetPopupName: 'Enw Ffenestr Bop',
	title: 'Dolen',
	toAnchor: 'Dolen at angor yn y testun',
	toEmail: 'E-bost',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Dolen',
	type: 'Math y Ddolen',
	unlink: 'Datgysylltu',
	upload: 'Lanlwytho'
} );
